|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r73192 - sandbox/conversion/boost/conversion
From: vicente.botet_at_[hidden]
Date: 2011-07-17 13:54:30
Author: viboes
Date: 2011-07-17 13:54:29 EDT (Sun, 17 Jul 2011)
New Revision: 73192
URL: http://svn.boost.org/trac/boost/changeset/73192
Log:
conversion: rename mcf by implicitly and mat to lvalue
Text files modified:
sandbox/conversion/boost/conversion/assignable_to.hpp | 9 +++++++--
sandbox/conversion/boost/conversion/convertible_from.hpp | 13 +++++++++----
2 files changed, 16 insertions(+), 6 deletions(-)
Modified: sandbox/conversion/boost/conversion/assignable_to.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/assignable_to.hpp (original)
+++ sandbox/conversion/boost/conversion/assignable_to.hpp 2011-07-17 13:54:29 EDT (Sun, 17 Jul 2011)
@@ -12,7 +12,7 @@
/*!
@file
@brief
- Defines the free function @c mat.
+ Defines the free function @c lvalue.
*/
#ifndef BOOST_CONVERSION_ASSIGNABLE_TO_HPP
#define BOOST_CONVERSION_ASSIGNABLE_TO_HPP
@@ -106,8 +106,13 @@
//! The result is able to transform conversion by convert_to calls and assignments by assign_to calls.
//! @NoThrow.
+ //~ template <typename Target>
+ //~ assignable_to<Target> mat(Target& r)
+ //~ {
+ //~ return assignable_to<Target>(r);
+ //~ }
template <typename Target>
- assignable_to<Target> mat(Target& r)
+ assignable_to<Target> lvalue(Target& r)
{
return assignable_to<Target>(r);
}
Modified: sandbox/conversion/boost/conversion/convertible_from.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/convertible_from.hpp (original)
+++ sandbox/conversion/boost/conversion/convertible_from.hpp 2011-07-17 13:54:29 EDT (Sun, 17 Jul 2011)
@@ -12,7 +12,7 @@
/*!
@file
@brief
- Defines the free function @c mcf.
+ Defines the free function @c implicitly.
*/
#ifndef BOOST_CONVERSION_CONVERTIBLE_FROM_HPP
#define BOOST_CONVERSION_CONVERTIBLE_FROM_HPP
@@ -30,7 +30,7 @@
//! wrapper providing implicit conversion operation to any type extrinsicaly implicit convertible from @c Source.
//! This wrapper is used indirectly through the @mcf function to pass a @c Source parameter to a function waiting a parameter @c Target
//! extrinsicaly convertible from it.
//!
//! Requires @c Source must be CopyConstructible
@@ -71,12 +71,17 @@
//! static void fct()
//! {
//! T v;
- //! std::cout << f(mcf(v)) << " called" << std::endl;
+ //! std::cout << f(implicitly(v)) << " called" << std::endl;
//! }
//! };
//! @endcode
+ //~ template <typename Source>
+ //~ convertible_from<Source> implicitly(Source s)
+ //~ {
+ //~ return convertible_from<Source>(s);
+ //~ }
template <typename Source>
- convertible_from<Source> mcf(Source s)
+ convertible_from<Source> implicitly(Source s)
{
return convertible_from<Source>(s);
}
@@ -30,7 +30,7 @@
//! wrapper providing implicit conversion operation to any type extrinsicaly implicit convertible from @c Source.
- //! This wrapper is used indirectly through the @mcf function to pass a @c Source parameter to a function waiting a parameter @c Target
+ //! This wrapper is used indirectly through the @implicitly function to pass a @c Source parameter to a function waiting a parameter @c Target
//! extrinsicaly convertible from it.
//!
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk